export type Options = {
	/** @deprecated `!doctype(html)` is now valid poggies code, use that instead. */
	doctype?: string | false
}
/**
 * Importer function for `import` statements.
 * @param path The path of the file to import
 * @returns Poggies source code
 */
export type Importer = (path: string | URL) => string
export interface PoggiesOptions {
	/**
	 * Name of the main document. Used for error messages, often the path.
	 * @default "<start>"
	 */
	name?: string
	/**
	 * Importer function for `$$component from "path"` statements. Defaults to `readTextFileSync` in Deno and Node.js (or compatible runtimes).
	 * @param path The path of the file to import
	 * @returns Poggies source code
	 */
	importer?: Importer
}
export type RenderFunction = (input: Record<string, unknown>) => Promise<string>
export declare class Poggies {
	private nodes
	private func
	/** The body of the function. Available before calling compile() or javascript() */
	js: string
	constructor(source: string, { importer, name }?: PoggiesOptions)
	/** Compiles the Poggies document into a function that can be called to return the rendered HTML */
	compile(): RenderFunction
	/**
	 * `async function(__INPUT__) { ${this.js} }`.
	 * Similar to this.compile().toString(), but doesn't actually compile a function.
	 */
	javascript(): string
	/** Renders this Poggies document with some given variables */
	render(input?: Record<string, unknown>, options?: Options): Promise<string>
}
export type PathLike = string | URL
export type RenderFileOptions = Options & PoggiesOptions & {
	cache?: boolean
}
/** Coggers promise-style template function */
export declare function renderFile(
	file: PathLike,
	input?: Record<string, unknown>,
	options?: Options & PoggiesOptions & {
		cache?: boolean
	},
): Promise<string>
/** Express-style template function */
export declare function express(
	file: string,
	input: Record<string, unknown>,
	options: Options & PoggiesOptions & {
		cache?: boolean
	},
	callback: (error: unknown, html?: string) => unknown,
): void
